@@ -82,6 +82,10 @@ def PlotGravPres(PlanetList, Params):
         axes[1].plot(Planet.P_MPa*FigLbl.PmultFull, Planet.r_m[:-1]/1e3,
                      label=legLbl, linewidth=Style.LW_std)
 
+    if FigMisc.FORCE_0_EDGES:
+        [ax.set_ylim(bottom=0) for ax in axes]
+        [ax.set_xlim(left=0) for ax in axes]
+
     if Params.LEGEND:
         axes[1].legend()
 
@@ -264,6 +268,10 @@ def PlotHydrosphereProps(PlanetList, Params):
                             color=thisColor, linewidth=Style.LW_sound,
                             linestyle=Style.LS[Planet.Ocean.comp])
 
+
+    if FigMisc.FORCE_0_EDGES:
+        axPrho.set_ylim(top=0)
+
     # Limit Tmin so the relevant plot can better show what's going on in the ocean
     axTz.set_xlim(left=FigMisc.TminHydro)
 
@@ -281,6 +289,7 @@ def PlotHydrosphereProps(PlanetList, Params):
                 adj = -0.06*rhoRange
             else:
                 adj = 0.06*rhoRange
+            Padj = 0.03*np.abs(np.diff(axPrho.get_ylim())[0])
 
             if phase == 0:
                 loc = np.where(Pall_MPa == np.min(Pall_MPa[phases == 0]))[0]
@@ -290,7 +299,7 @@ def PlotHydrosphereProps(PlanetList, Params):
                     adj2 = -adj
                 else:
                     adj2 = 0
-                axPrho.text(rhoAll_kgm3[loc] + 3*adj + adj2, (Pall_MPa[loc] + adj)*FigLbl.PmultHydro,
+                axPrho.text(rhoAll_kgm3[loc] + 3*adj + adj2, (Pall_MPa[loc] + Padj)*FigLbl.PmultHydro,
                             'liquid', ha='center', va='center', fontsize=FigLbl.TS_hydroLabels)
             else:
                 if phase == Constants.phaseClath:
@@ -399,6 +408,18 @@ def PlotSilTradeoff(PlanetList, Params):
 
 def PlotPorosity(PlanetList, Params):
 
+    for Planet in PlanetList:
+        nonzeroPhi = Planet.phi_frac > 0
+        Planet.phiPlot = Planet.phi_frac[nonzeroPhi]
+        Planet.zPlot = Planet.z_m[:-1][nonzeroPhi]
+        Planet.Pplot = Planet.P_MPa[nonzeroPhi]
+        iPhaseChanges = np.where(np.diff(Planet.phase[nonzeroPhi]) != 0)[0] + 1
+        if np.size(iPhaseChanges) > 0:
+            # Add a nan so we don't get a line from porous ice to rock if both are modeled
+            Planet.phiPlot = np.insert(Planet.phiPlot, iPhaseChanges, np.nan)
+            Planet.zPlot = np.insert(Planet.zPlot, iPhaseChanges, np.nan)
+            Planet.Pplot = np.insert(Planet.Pplot, iPhaseChanges, np.nan)
+
     # Plot dual-axis plot for first entry in PlanetList (usually a main profile), unless we are already doing comparison plots
     if os.path.dirname(Params.FigureFiles.vporeDbl) != 'Comparison':
         Planet = PlanetList[0]
@@ -418,9 +439,11 @@ def PlotPorosity(PlanetList, Params):
         Pax.set_ylabel(FigLbl.PlabelFull)
         fig.suptitle(f'{Planet.name}{FigLbl.poreTitle}')
 
-        ax.plot(Planet.phi_frac[Planet.phi_frac >= Planet.Sil.phiMin_frac]*FigLbl.phiMult,
-                Planet.z_m[:-1][Planet.phi_frac >= Planet.Sil.phiMin_frac]/1e3,
+        ax.plot(Planet.phiPlot*FigLbl.phiMult, Planet.zPlot/1e3,
                 label=Planet.label, linewidth=Style.LW_std)
+        if FigMisc.FORCE_0_EDGES:
+            ax.set_ylim(top=0)
+            ax.set_xlim(left=0)
 
         if Params.LEGEND:
             ax.legend()
@@ -452,13 +475,14 @@ def PlotPorosity(PlanetList, Params):
             legLbl = Planet.label
             if (not Params.ALL_ONE_BODY) and FigLbl.BODYNAME_IN_LABEL:
                 legLbl = f'{Planet.name} {legLbl}'
-            axes[0].plot(Planet.phi_frac[Planet.phi_frac >= Planet.Sil.phiMin_frac]*FigLbl.phiMult,
-                         Planet.z_m[:-1][Planet.phi_frac >= Planet.Sil.phiMin_frac]/1e3,
+            axes[0].plot(Planet.phiPlot*FigLbl.phiMult, Planet.zPlot/1e3,
                          label=legLbl, linewidth=Style.LW_std)
-            axes[1].plot(Planet.phi_frac[Planet.phi_frac >= Planet.Sil.phiMin_frac]*FigLbl.phiMult,
-                         Planet.P_MPa[Planet.phi_frac >= Planet.Sil.phiMin_frac]*FigLbl.PmultFull,
+            axes[1].plot(Planet.phiPlot*FigLbl.phiMult, Planet.Pplot*FigLbl.PmultFull,
                          label=legLbl, linewidth=Style.LW_std)
 
+    if FigMisc.FORCE_0_EDGES:
+        [ax.set_ylim(top=0) for ax in axes]
+        [ax.set_xlim(left=0) for ax in axes]
     if Params.LEGEND:
         axes[1].legend()
 
@@ -533,6 +557,10 @@ def PlotSeismic(PlanetList, Params):
         axes[1,0].legend()
         axes[1,1].legend()
 
+    if FigMisc.FORCE_0_EDGES:
+        [ax.set_xlim(left=0) for ax in axf if ax.get_xscale() != 'log']
+        [ax.set_ylim(bottom=0) for ax in axf]
+
     plt.tight_layout()
     fig.savefig(Params.FigureFiles.vseis, format=FigMisc.figFormat, dpi=FigMisc.dpi)
     log.debug(f'Seismic plot saved to file: {Params.FigureFiles.vseis}')
@@ -604,6 +632,23 @@ def PlotWedge(PlanetList, Params):
         else:
             coreLine = ''
 
+        if FigMisc.LABEL_RADII:
+            RionosLbl = f'{FigLbl.ionosTickLbl}: '
+            RsurfLbl = f'{FigLbl.surfTickLbl}: '
+            RclathLbl = f'{FigLbl.clathTickLbl}: '
+            RconvLbl = f'{FigLbl.convIceTickLbl}: '
+            RoceanLbl = f'{FigLbl.oceanTickLbl}: '
+            RmantLbl = f'{FigLbl.mantTickLbl}: '
+            RcoreLbl = f'{FigLbl.coreTickLbl}: '
+        else:
+            RionosLbl = ''
+            RsurfLbl = ''
+            RclathLbl = ''
+            RconvLbl = ''
+            RoceanLbl = ''
+            RmantLbl = ''
+            RcoreLbl = ''
+
         if 'Comet' in Planet.Sil.mantleEOS:
             silLine = 'Comet 67P'
         else:
@@ -658,7 +703,7 @@ def PlotWedge(PlanetList, Params):
             # @@@@@@@@@
             # Ice shell
             # @@@@@@@@@
-            rTicks.append(R_km)
+            rTicks.append(f'{RsurfLbl}{R_km:.0f}')
             rTickRefs.append(R_km/rMax_km)
 
             # Starting with ice I or clathrates
@@ -737,7 +782,7 @@ def PlotWedge(PlanetList, Params):
             # @@@@@@@@@@@
             if Planet.D_km > 0:
                 if FigMisc.WEDGE_ICE_TICKS or (Planet.zb_km/R_km >= FigMisc.minzbRratio_frac and Planet.D_km/R_km >= FigMisc.minzbRratio_frac):
-                    rTicks.append(R_km - Planet.zb_km)
+                    rTicks.append(f'{RoceanLbl}{R_km - Planet.zb_km:.0f}')
                     rTickRefs.append((R_km - Planet.zb_km)/rMax_km)
 
                 # Ocean outer boundary to use as clip path
@@ -773,7 +818,7 @@ def PlotWedge(PlanetList, Params):
         # @@@@@@@@@
         # Silicates
         # @@@@@@@@@
-        rTicks.append(Planet.Sil.Rmean_m/1e3)
+        rTicks.append(f'{RmantLbl}{Planet.Sil.Rmean_m/1e3:.0f}')
         rTickRefs.append(Planet.Sil.Rmean_m/1e3/rMax_km)
 
         # Outer boundary around silicate layer to use as clip path for gradients
@@ -818,7 +863,7 @@ def PlotWedge(PlanetList, Params):
         # Iron core
         # @@@@@@@@@
         if Planet.Do.Fe_CORE:
-            rTicks.append(Planet.Core.Rmean_m/1e3)
+            rTicks.append(f'{RcoreLbl}{Planet.Core.Rmean_m/1e3:.0f}')
             rTickRefs.append(Planet.Core.Rmean_m/1e3/rMax_km)
 
             # FeS layer
@@ -845,7 +890,7 @@ def PlotWedge(PlanetList, Params):
             for rTick in rTickRefs:
                 ax.axhline(y=rTick, xmin=0, xmax=0.5, color=Color.wedgeMarkRadii,
                            ls=Style.LS_markRadii, lw=Style.LW_markRadii)
-        ax.set_yticklabels(np.array(rTicks, dtype=np.int_), fontsize=Style.TS_ticks)
+        ax.set_yticklabels(np.array(rTicks), fontsize=Style.TS_ticks)
         [ax.spines[side].set_visible(False) for side in ['top', 'right', 'bottom']]
         ax.get_xaxis().set_visible(False)
         ax.set_ylabel(FigLbl.wedgeRadius, fontsize=Style.TS_ticks)
