@@ -20,6 +20,9 @@ def SetupInit(Planet, Params):
     # Print version number
     log.debug(f'-- PlanetProfile v{ppVerNum} --')
     if ppVerNum[-3:] == 'dev': log.debug('This version is in development.')
+    # Print body name
+    log.info(f'Body name: {Planet.name}')
+    log.debug(f'Input file: {Planet.fname}')
 
     # Check dependency compatibility
     CheckCompat('seafreeze')  # SeaFreeze
@@ -166,12 +169,9 @@ def SetupInit(Planet, Params):
             log.warning('Ocean.deltaT is not set--defaulting to 0.1 K. This may not be precise enough ' +
                         'for shallow oceans or fine control over ice shell thickness calculations. ' +
                         'It is recommended to set Ocean.deltaT manually in the PPBody.py file.')
-        # Check ocean parameter space, and prevent setup from taking forever if we have a deep ocean:
+        # Check ocean parameter space and load EOS
         if Planet.Ocean.THydroMax_K < Planet.Bulk.Tb_K:
             raise ValueError(f'Ocean.THydroMax_K of {Planet.Ocean.THydroMax_K} is less than Bulk.Tb_K of {Planet.Bulk.Tb_K}.')
-        elif Planet.Bulk.Tb_K + 30 < Planet.Ocean.THydroMax_K:
-            TOcean_K = np.concatenate((np.linspace(Planet.Bulk.Tb_K, Planet.Bulk.Tb_K + 30, int(100/Planet.Ocean.deltaT), endpoint=False),
-                                       np.arange(Planet.Bulk.Tb_K + 30, Planet.Ocean.THydroMax_K, 2)))
         else:
             TOcean_K = np.arange(Planet.Bulk.Tb_K, Planet.Ocean.THydroMax_K, Planet.Ocean.deltaT)
         Planet.Ocean.EOS = GetOceanEOS(Planet.Ocean.comp, Planet.Ocean.wOcean_ppt, POcean_MPa, TOcean_K,
@@ -179,9 +179,27 @@ def SetupInit(Planet, Params):
                                        scalingType=Planet.Ocean.MgSO4scalingType, FORCE_NEW=Params.FORCE_EOS_RECALC,
                                        phaseType=Planet.Ocean.phaseType, EXTRAP=Params.EXTRAP_OCEAN)
         # Get separate, simpler EOS for evaluating the melting curve
+        if Planet.Do.BOTTOM_ICEV:
+            TmeltI_K = np.linspace(Planet.Bulk.Tb_K - 0.01, Planet.Bulk.Tb_K + 0.01, 11)
+            TmeltIII_K = np.linspace(Planet.Bulk.TbIII_K - 0.01, Planet.Bulk.TbIII_K + 0.01, 11)
+            TmeltV_K = np.linspace(Planet.Bulk.TbV_K - 0.01, Planet.Bulk.TbV_K + 0.01, 11)
+            Tmelt_K = np.concatenate((TmeltI_K, TmeltIII_K, TmeltV_K))
+            if Planet.PfreezeUpper_MPa < 700:
+                log.info(f'PfreezeUpper_MPa is set to {Planet.PfreezeUpper_MPa}, but Do.BOTTOM_ICEV is True and ' +
+                         'ice V is stable up to 700 MPa. PfreezeUpper_MPa will be raised to this value.')
+                Planet.PfreezeUpper_MPa = 700
+        elif Planet.Do.BOTTOM_ICEIII:
+            TmeltI_K = np.linspace(Planet.Bulk.Tb_K - 0.01, Planet.Bulk.Tb_K + 0.01, 11)
+            TmeltIII_K = np.linspace(Planet.Bulk.TbIII_K - 0.01, Planet.Bulk.TbIII_K + 0.01, 11)
+            Tmelt_K = np.concatenate((TmeltI_K, TmeltIII_K))
+            if Planet.PfreezeUpper_MPa < 700:
+                log.info(f'PfreezeUpper_MPa is set to {Planet.PfreezeUpper_MPa}, but Do.BOTTOM_ICEIII is True and ' +
+                         'ice V is stable up to 400 MPa. PfreezeUpper_MPa will be raised to this value.')
+                Planet.PfreezeUpper_MPa = 400
+        else:
+            Tmelt_K = np.linspace(Planet.Bulk.Tb_K - 0.01, Planet.Bulk.Tb_K + 0.01, 11)
         Pmelt_MPa = np.arange(Planet.PfreezeLower_MPa, Planet.PfreezeUpper_MPa, Planet.PfreezeRes_MPa)
-        Planet.Ocean.meltEOS = GetOceanEOS(Planet.Ocean.comp, Planet.Ocean.wOcean_ppt, Pmelt_MPa,
-                                           np.linspace(Planet.Bulk.Tb_K - 0.01, Planet.Bulk.Tb_K + 0.01, 11), None,
+        Planet.Ocean.meltEOS = GetOceanEOS(Planet.Ocean.comp, Planet.Ocean.wOcean_ppt, Pmelt_MPa, Tmelt_K, None,
                                            phaseType=Planet.Ocean.phaseType, FORCE_NEW=True, MELT=True)
 
     # Make sure convection checking outputs are set if we won't be modeling them
@@ -274,7 +292,7 @@ def SetupInit(Planet, Params):
             Planet.Sil.poreEOS = GetOceanEOS(Planet.Sil.poreComp, Planet.Sil.wPore_ppt, Ppore_MPa, Tpore_K,
                                              Planet.Ocean.MgSO4elecType, rhoType=Planet.Ocean.MgSO4rhoType,
                                              scalingType=Planet.Ocean.MgSO4scalingType, FORCE_NEW=Params.FORCE_EOS_RECALC,
-                                             phaseType=Planet.Ocean.phaseType, EXTRAP=Params.EXTRAP_OCEAN)
+                                             phaseType=Planet.Ocean.phaseType, EXTRAP=Params.EXTRAP_OCEAN, PORE=True)
 
             # Make sure Sil.phiRockMax_frac is set in case we're using a porosType that doesn't require it
             if Planet.Sil.phiRockMax_frac is None or Planet.Sil.porosType != 'Han2014':
@@ -369,7 +387,8 @@ def SetupFilenames(Planet, Params, exploreAppend=None, figExploreAppend=None):
     else:
         inductBase = None
     DataFiles = DataFilesSubstruct(datPath, saveBase + saveLabel, Planet.Ocean.comp, inductBase=inductBase,
-                                   exploreAppend=exploreAppend)
+                                   exploreAppend=exploreAppend, EXPLORE=(Params.DO_INDUCTOGRAM or
+                                       Params.DO_EXPLOREOGRAM or Params.INDUCTOGRAM_IN_PROGRESS))
     FigureFiles = FigureFilesSubstruct(figPath, saveBase + saveLabel, FigMisc.xtn,
                                        comp=Planet.Ocean.comp, inductBase=inductBase,
                                        exploreAppend=figExploreAppend)
@@ -405,7 +424,7 @@ def SetupLayers(Planet):
 def SetCMR2strings(Planet):
     # Create strings to describe input MoI in terminal outputs and plots/tables
     if Planet.Bulk.CuncertaintyLower == Planet.Bulk.CuncertaintyUpper:
-        Planet.CMR2strPrint = f'{Planet.Bulk.Cmeasured:.4f} ± {Planet.Bulk.CuncertaintyLower:.4f}'
+        Planet.CMR2strPrint = f'{Planet.Bulk.Cmeasured:.4f} +/- {Planet.Bulk.CuncertaintyLower:.4f}'
         Planet.CMR2str = f'{Planet.Bulk.Cmeasured}\pm{Planet.Bulk.CuncertaintyLower}'
         Planet.CMR2str5 = f'{Planet.Bulk.Cmeasured:.5f}\pm{Planet.Bulk.CuncertaintyLower:.5f}'
     else:
